@@ -1,7 +1,7 @@
 package MARC::Moose;
 # ABSTRACT: Moose based MARC records set of tools
-$MARC::Moose::VERSION = '1.0.17';
-use Moose 1.00;
+$MARC::Moose::VERSION = '1.0.18';
+use Moose;
 
 use Carp;
 
@@ -22,7 +22,7 @@ MARC::Moose - Moose based MARC records set of tools
 
 =head1 VERSION
 
-version 1.0.17
+version 1.0.18
 
 =head1 DESCRIPTION
 
